@@ -2,7 +2,7 @@ print.MCA <- function (x, file = NULL, sep = ";", ...){
     res.mca <- x
     if (!inherits(res.mca, "MCA")) stop("non convenient data")
     cat("**Results of the Multiple Correspondance Analysis (MCA)**\n\n")
-    cat("There are", nrow(res.mca$call$X), "individuals, caracterized by",
+    cat("There are", nrow(res.mca$call$X), "individuals, characterized by",
         ncol(res.mca$call$X), "variables\n\n")
     cat("*Les resultats de votre analyse sont disponibles dans les objets suivants :\n\n")
     res <- array("", c(22, 2), list(1:22, c("nom", "description")))
